#*****************************************************************************
#   Copyright 2004-2008 Steve Menard
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#   
#*****************************************************************************

import _winreg

def getDefaultJVMPath() :
    try :
        jreKey = _winreg.OpenKey(_winreg.HKEY_LOCAL_MACHINE, r"SOFTWARE\JavaSoft\Java Runtime Environment")
        cv = _winreg.QueryValueEx(jreKey, "CurrentVersion")
        versionKey = _winreg.OpenKey(jreKey, cv[0])
        _winreg.CloseKey(jreKey)
       
        cv = _winreg.QueryValueEx(versionKey, "RuntimeLib")
        _winreg.CloseKey(versionKey)
        
        return cv[0]
    except WindowsError, ex :
        pass
        
    return None